/*
 * Copyright 2014-2017 Jiří Janoušek <janousek.jiri@gmail.com>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met: 
 * 
 * 1. Redistributions of source code must retain the above copyright notice, this
 *    list of conditions and the following disclaimer. 
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 *    this list of conditions and the following disclaimer in the documentation
 *    and/or other materials provided with the distribution. 
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR
 * ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

namespace Nuvola
{
#if !FLATPAK
public async void delete_desktop_files()
{
	var pattern = new PatternSpec("nuvolaplayer3-*.desktop");
	var dir = new Diorite.XdgStorage().user_data_dir.get_child("applications");
	try
	{
		var enumerator = yield dir.enumerate_children_async(
			FileAttribute.STANDARD_NAME, FileQueryInfoFlags.NOFOLLOW_SYMLINKS);
		FileInfo info;
		while ((info = enumerator.next_file(null)) != null)
		{
			var name = info.get_name();
			if (pattern.match_string(name))
			{
				
				var file = dir.get_child(name);
				try
				{
					yield file.delete_async();
				}
				catch (GLib.Error e)
				{
					warning("Failed to delete desktop file %s. %s", file.get_path(), e.message);
				}
				
			}
		}
	}
	catch (GLib.Error e)
	{
		warning("Directory enumeration failed: %s. %s\n", dir.get_path(), e.message);
	}
}
#endif

private static HashTable<string,string> desktop_categories = null;

public HashTable<string, string> get_desktop_categories()
{
	if (desktop_categories == null)
	{
		desktop_categories = new HashTable<string, string>(str_hash, str_equal);
		desktop_categories["AudioVideo"] = _("Multimedia");
		desktop_categories["Audio"] = _("Audio");
		desktop_categories["Video"] = _("Video");
		desktop_categories["Development"] = _("Development");
		desktop_categories["Education"] = _("Education");
		desktop_categories["Game"] = _("Game");
		desktop_categories["Graphics"] = _("Graphics");
		desktop_categories["Network"] = _("Network");
		desktop_categories["Office"] = _("Office");
		desktop_categories["Science"] = _("Science");
		desktop_categories["Settings"] = _("Settings");
		desktop_categories["System"] = _("System Tools");
		desktop_categories["Utility"] = _("Accessories");
		desktop_categories["Other"] = _("Other");
	}
	return desktop_categories;
}

public string? get_desktop_category_name(string id)
{
	return get_desktop_categories()[id];
}

} // namespace Nuvola
